@@ -1,5 +1,6 @@
 from wraptor.decorators.memoize import memoize
 from wraptor.decorators.throttle import throttle
 from wraptor.decorators.timeout import timeout, TimeoutException
+from wraptor.decorators.exception_catcher import exception_catcher
 
-__all__ = ['memoize', 'throttle', 'timeout', 'TimeoutException']
+__all__ = ['memoize', 'throttle', 'timeout', 'TimeoutException', 'exception_catcher']
